% if report.sales:

#### ${ _("Sales") }

${ _("Code") } | ${ _("Sales Person") } | ${ _("Client") } | ${ _("Value") }
% for sale in report.sales:
${ sale.identifier } | ${ sale.salesperson } | ${ sale.client } | ${ format_price(sale.value) }
% for details, values in report.sales[sale].items():
| ${ details[0] } | ${ details[1] } | ${ format_price(values[0]) } (${ values[1] }x)
% endfor % endfor

% endif